/*
********************************************************************
* IBM Confidential                                                 *
*                                                                  *
* OCO Source Materials                                             *
*                                                                  *
* 5724-E76 and 5724-E77                                            *
*                                                                  *
* (C) Copyright IBM Corp. 2001, 2003, 2004                         *
*                                                                  *
* The source code for this program is not published or otherwise   *
* divested of its trade secrets, irrespective of what has been     *
* deposited with the U.S. Copyright Office.                        *
********************************************************************
*/
package com.ibm.portal.um.portletservice.legacy;

import org.apache.jetspeed.portlet.event.ActionEvent;
import org.apache.jetspeed.portlet.service.PortletService;

import com.ibm.portal.um.PumaController;
import com.ibm.portal.um.PumaLocator;
import com.ibm.portal.um.PumaProfile;

/**
 * This Interface can be used to access the UserManagement component of WebSphere Portal <br>
 * from a legacy portlet. An instance can be retrieved via querying the PortletRegistryService 
 * 
 * <pre>
 * PumaHome service = (PumaHome) getPortletContext().getService(PumaHome.class);
 * </pre>
 *
 * The returned instance provides a way to access the three views to the user repository<br> 
 * 
 * <Code>com.ibm.portal.um.PumaProfile</CODE> <br>
 * <Code>com.ibm.portal.um.PumaController</CODE> <br>
 * <Code>com.ibm.portal.um.PumaLocator</CODE> <br>
 * 
 * @see com.ibm.portal.um.PumaProfile
 * @see com.ibm.portal.um.PumaLocator
 * @see com.ibm.portal.um.PumaController
 * 
 * @ibm-spi
 * @since 5.1.0.1 
 */
public interface PumaHome extends PortletService
{

    /**
     * The returned instance of <Code>PumaController</COde> can be used to read/modify attributes
     * for a <code>com.ibm.portal.um.Principal</CODE>
     *  
     * @param aRequest <code>NULL</CODE> is not allowed as parameter
     * @return a handle to the read/write PUMA service
     */
    PumaController getController(ActionEvent aEvent);

    /**
     * The returned instance of <Code>PumaLocator</COde> can be used to find <code>com.ibm.portal.um.Principal</CODE>
     *  
     * @param aRequest <code>NULL</CODE> is not allowed as parameter
     * @return a handle to the find PUMA service
     */
    PumaLocator getLocator(org.apache.jetspeed.portlet.PortletRequest aRequest);

    /**
     * The returned instance of <Code>PumaProfile</COde> can be used to read attributes
     * for a <code>Principal</CODE>
     *  
     * @param aRequest <code>NULL</CODE> is not allowed as parameter
     * @return a handle to the read PUMA service
     */
    PumaProfile getProfile(org.apache.jetspeed.portlet.PortletRequest aRequest);

}
