/*
********************************************************************
* IBM Confidential                                                 *
*                                                                  *
* OCO Source Materials                                             *
*                                                                  *
* 5724-E76 and 5724-E77                                            *
*                                                                  *
* (C) Copyright IBM Corp. 2001, 2003                               *
*                                                                  *
* The source code for this program is not published or otherwise   *
* divested of its trade secrets, irrespective of what has been     *
* deposited with the U.S. Copyright Office.                        *
********************************************************************
*/
package com.ibm.wps.portletservice.portletmenu;

import com.ibm.wps.portlet.menu.MenuNode;
import com.ibm.wps.portlet.menu.MenuTree;
import com.ibm.wps.portlet.menu.MenuTreeException;
import com.ibm.wps.portlet.menu.MenuTreeTopologyCtrl;

/**
 * The {@link MemoryMenuTreeTopologyCtrl} interface allows to add a complete {@link MenuTree} as a subtree
 * of a memory menu tree.
 * 
 * <P>To include an existing instance of {@link MenuTree} into an in-Memory tree,
 * so that the new child of the in-Memory tree node refers to the root node of the tree to be included,
 * the destination instance of the in-memory {@link MenuTree}, which is returned by {@link MemoryMenuService},
 * must expose the controller interface {@link MemoryMenuTreeTopologyCtrl}.</P>
 * 
 * @ibm-spi
 * @since 5.0
 * 
 * @see MenuTreeTopologyCtrl
 */
public interface MemoryMenuTreeTopologyCtrl extends MenuTreeTopologyCtrl
{
    /**
     * Add a child node that refers to the root node of another tree model to a parent node. 
     * 
     * @param model model tree the child node refers to
     * 
     * @param parent  parent node that gets a child node
     * 
     * @return child node
     * 
     * @exception MenuTreeException
     *                   if operation fails
     * 
     * @see MenuNode
     */
    public MenuNode addNode(MenuTree model,MenuNode parent) throws MenuTreeException ;  
}

